import { useEffect } from "preact/hooks";

export const useStream = <T>(
  stream: ReadableStream<T>,
  onData: (data: T) => void,
  onError: (err: Error) => void,
) => {
  const reader = stream.getReader();
  const read = async () => {
    const { done, value } = await reader.read();
    if (done) {
      reader.releaseLock();
      return;
    }
    onData(value);
    read();
  };
  read();
};

export const useRemoteStream = <T>(
  url: string,
  onData: (data: T) => void,
  onError: (err: Error) => void,
) => {
  useEffect(() => {
    const stream = new ReadableStream({
      async start(controller) {
        const res = await fetch(url);
        res.body?.pipeThrough(new TextDecoderStream())
          .pipeTo(
            new WritableStream({
              write(chunk) {
                controller.enqueue(chunk);
              },
            }),
          );
      },
    });
    useStream(stream, onData, onError);
  }, [url]);
};
